@@ -318,11 +318,12 @@ def check_system_deps(
                 raise ValueError(f"Malformed dependency: {dep}")
             if len(keys) == 1:
                 dep_name = keys[0]
+                dep_kind = dep[dep_name].get("kind", "app")
             elif "name" in keys:
                 dep_name = dep["name"]
+                dep_kind = dep.get("kind", "app")
             else:
                 raise ValueError(f"Malformed dependency: {dep}")
-            dep_kind = dep[dep_name].get("kind", "app")
         else:
             dep_name = re.split("[=<>]", dep)[0]
             dep_kind = "app"
@@ -478,12 +479,16 @@ def get_latest_project_status(wdir: str | None = None) -> ProjectStatus | None:
         return statuses[-1]  # type: ignore
 
 
-def detect_project_name(wdir: str | None = None) -> str:
+def detect_project_name(
+    wdir: str | None = None, prepend_owner: bool = True
+) -> str:
     """Detect a Calkit project owner and name."""
     ck_info = load_calkit_info(wdir=wdir)
     name = ck_info.get("name")
+    if name is not None and not prepend_owner:
+        return name
     owner = ck_info.get("owner")
-    if name is None or owner is None:
+    if name is None and owner is None:
         try:
             url = Repo(path=wdir).remote().url
         except ValueError:
@@ -494,7 +499,9 @@ def detect_project_name(wdir: str | None = None) -> str:
         name = project_name
     if owner is None:
         owner = owner_name
-    return f"{owner}/{name}"
+    if prepend_owner:
+        return f"{owner}/{name}"
+    return name
 
 
 def get_dep_version(dep_name: str) -> str | None:
